@@ -17,7 +17,7 @@ def version():
 
     :return: 返回版本号
     """
-    return '2.2.13'
+    return '2.2.13.1'
 
 
 def f_debug():
