@@ -36,6 +36,9 @@ def 颜色(text, 色选="None"):
     :param 色选: 你要加的颜色，现在的可选颜色是：紫色，红色，黄色，蓝色，青色，绿色和相对应的背景色
     :return: 格式化后的内容
     """
+    import colorama
+    colorama.init(autoreset=True)#针对其他控制台的补丁
+
     if 色选 == "紫色":
         return f"\033[35m{text}\033[0m"
     elif 色选 == "红色":
